#
# spec file for package ghc-hashable
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name hashable
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.4.3.0
Release:        2.1
Summary:        A class for types that can be converted to a hash value
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-deepseq-prof
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-filepath-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-HUnit-prof
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-random-devel
BuildRequires:  ghc-random-prof
BuildRequires:  ghc-test-framework-devel
BuildRequires:  ghc-test-framework-hunit-devel
BuildRequires:  ghc-test-framework-hunit-prof
BuildRequires:  ghc-test-framework-prof
BuildRequires:  ghc-test-framework-quickcheck2-devel
BuildRequires:  ghc-test-framework-quickcheck2-prof
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-unix-prof
%endif

%description
This package defines a class, 'Hashable', for types that can be converted to a
hash value. This class exists for the benefit of hashing-based data structures.
The package provides instances for basic types and a way to combine hash
values.

The 'Hashable' 'hash' values are not guaranteed to be stable across library
versions, operating systems or architectures. For stable hashing use named
hashes: SHA256, CRC32 etc.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGES.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Tue Oct  3 2023 Peter Simons <psimons@suse.com>
- Update hashable to version 1.4.3.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat Jul 29 2023 Peter Simons <psimons@suse.com>
- Update hashable to version 1.4.3.0.
  [#]# Version 1.4.3.0
  * Export `defaultHashWithSalt` and `defaultHash`.
  * Fix issue of tuples with 0 first component causing all-zero state.
  * Change `hashInt` to mix bits more.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sun Mar 12 2023 Peter Simons <psimons@suse.com>
- Update hashable to version 1.4.2.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Jan  5 2023 Peter Simons <psimons@suse.com>
- Update hashable to version 1.4.2.0.
  [#]# Version 1.4.2.0
  * Fix the foreign signature of `getThreadId`
    https://github.com/haskell-unordered-containers/hashable/pull/263
  * Drop support for GHCs prior GHC-8.2
    The recent `unordered-containers` releases support only GHC-8.2+
  * Add instance for `OsString`, `PosixString`, `WindowsString` from `filepath-1.4.100.1`
  * Add `Hashable ByteArray` instance using `data-array-byte` compat package
  [#]# Version 1.4.1.0
  * Add instance for `Data.Array.Byte.ByteArray`.
  [#]# Version 1.4.0.2
  * Restore older GHC support
  * Support GHC-9.0.2
  [#]# Version 1.4.0.1
  * `text-2.0` compatibility
  [#]# Version 1.4.0.0
  * `Eq` is now a superclass of `Hashable`.
    Also `Eq1` is a superclass of `Hashable1` and `Eq2` is a superclass of `Hashable2`
    when exists.
  * Remove `Hashable1 Fixed` instance
  * Remove `Hashable1 Semi.Min/Max/...` instances as they don't have `Eq1` instance.
* Thu Jan  6 2022 Peter Simons <psimons@suse.com>
- Update hashable to version 1.3.5.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Nov  4 2021 psimons@suse.com
- Update hashable to version 1.3.5.0.
  [#]# Version 1.3.5.0
  * Add `Solo` instance (base-4.15+, GHC-9+)
* Thu Oct  7 2021 psimons@suse.com
- Update hashable to version 1.3.4.1.
  [#]# Version 1.3.4.1
  * Fix compilation on 32 bit platforms
  * Fix `Tree` instance
  [#]# Version 1.3.4.0
  * `Text` and `ByteString` hashes include length.
    This fixes a variant of https://github.com/haskell-unordered-containers/hashable/issues/74
    for texts and bytestrings.
    https://github.com/haskell-unordered-containers/hashable/pull/223
  * Use correct prime in `combine`.
    This should improve the hash quality of compound structures on 64bit systems.
    https://github.com/haskell-unordered-containers/hashable/pull/224
  * Add instance for types in `containers` package
    https://github.com/haskell-unordered-containers/hashable/pull/226
  * Change `Int`, `Int64` and `Word64` `hashWithSalt` slightly.
    https://github.com/haskell-unordered-containers/hashable/pull/227
* Wed Aug 25 2021 psimons@suse.com
- Update hashable to version 1.3.3.0.
  [#]# Version 1.3.3.0
  * `Text` hashing uses 64-bit FNV prime
  * Don't truncate Text hashvalues on 64bit Windows:
    https://github.com/haskell-unordered-containers/hashable/pull/211
* Thu May 20 2021 psimons@suse.com
- Update hashable to version 1.3.2.0.
  [#]# Version 1.3.2.0
  * Add `Hashable (Fixed a)` for `base <4.7` versions.
  * Add documentation:
  - `hashable` is not a stable hash
  - `hashWithSalt` may return negative values
  - there is `time-compat` with `Hashable` instances for `time` types.
  * Add `random-initial-seed` flag causing the initial seed
    to be randomized on each start of an executable using `hashable`.
* Mon Apr 26 2021 Ondřej Súkup <mimi.vx@gmail.com>
- remve obsollete fix for i586
* Sat Feb 20 2021 psimons@suse.com
- Update hashable to version 1.3.1.0.
  [#]# Version 1.3.1.0
  * Add `Hashable1` instances to `semigroups` types.
  * Use `ghc-bignum` with GHC-9.0
  * Use FNV-1 constants.
  * Make `hashable-examples` a test-suite
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Dec  8 2020 psimons@suse.com
- Update hashable to version 1.3.0.0 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Aug 31 2020 psimons@suse.com
- Update hashable to version 1.3.0.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Thu May  7 2020 Peter Simons <psimons@suse.com>
- Update Cabal file to get more accurate dependency information.
* Sun Dec 29 2019 psimons@suse.com
- Update hashable to version 1.3.0.0.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/hashable-1.3.0.0/src/CHANGES.md
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Fri Aug 17 2018 psimons@suse.com
- Update Cabal build information to support GHC 8.6.x.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update hashable to version 1.2.7.0.
  * Add `Hashable` and `Hashable1` instances for `Complex`
  * Fix undefined behavior in `hashable_fn_hash()` implementation
  due to signed integer overflow (#152)
  * Mark `Data.Hashable.Lifted` as `Trustworthy` (re SafeHaskell)
  * Support GHC 8.4
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Sat Jul  8 2017 psimons@suse.com
- Update to version 1.2.6.1 revision 2.
* Sun Jun 25 2017 psimons@suse.com
- Update to version 1.2.6.1 revision 1.
* Mon Mar 27 2017 psimons@suse.com
- Update to version 1.2.6.0 revision 1 with cabal2obs.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 1.2.5.0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.2.4.0 revision 0 with cabal2obs.
* Sun Jan 17 2016 mimi.vx@gmail.com
- update to 1.2.4.0
  * Add instances for: Unique, Version, Fixed, NonEmpty, Min, Max, Arg,
    First, Last, WrappedMonoid, Option
* Sun Jun 28 2015 mimi.vx@gmail.com
- update to 1.2.3.3
  * Support integer-simple.
* Sun Apr 12 2015 mimi.vx@gmail.com
- update to 1.2.3.2
  + disable SSE2 on i586 arch
  * Add support for GHC 7.10 typeRepFingerprint
  * Added support for random 1.1.*.
  * Silence integer literal overflow warning
  * Add support for GHC 7.10 `integer-gmp2` & `Natural`
  * Add instance for Data.Void
  * Make the SSE .cabal flags manual
  * Add an upper bound on bytestring
* Tue Sep  9 2014 peter.trommler@ohm-hochschule.de
- update to 1.2.2.0
  * several performance fixes including use of SSE and SSE2
  * Haskell Platform 2014.2.0.0
* Tue Sep  2 2014 peter.trommler@ohm-hochschule.de
- regenerate spec file
* Sat Aug 23 2014 peter.trommler@ohm-hochschule.de
- enable PowerPC builds
* Mon May  6 2013 peter.trommler@ohm-hochschule.de
- update to 1.1.2.5 from upstream
  * changelog not updated since 1.1.1.0
- version required for Haskell Platform 2013.2
- more transparent packaging (fewer macros)
* Thu Jun  7 2012 herbert@graeber-clan.de
- update to version 1.1.2.3
  spec file template generated by cabal2spec-0.25.5
* Sun Feb  5 2012 herbert@graeber-clan.de
- Initial package
